@@ -12,8 +12,6 @@ import (
 
 	"github.com/a8m/envsubst"
 	"github.com/adrg/xdg"
-	"github.com/k0sproject/k0sctl/analytics"
-	"github.com/k0sproject/k0sctl/integration/segment"
 	"github.com/k0sproject/k0sctl/phase"
 	"github.com/k0sproject/k0sctl/pkg/apis/k0sctl.k0sproject.io/v1beta1"
 	"github.com/k0sproject/k0sctl/pkg/retry"
@@ -68,19 +66,6 @@ var (
 		TakesFile: true,
 	}
 
-	analyticsFlag = &cli.BoolFlag{
-		Name:    "disable-telemetry",
-		Usage:   "Do not send anonymous telemetry",
-		EnvVars: []string{"DISABLE_TELEMETRY"},
-	}
-
-	ignoredUpgradeCheckFlag = &cli.BoolFlag{
-		Name:    "disable-upgrade-check",
-		Usage:   "Do not check for a k0sctl upgrade",
-		EnvVars: []string{"DISABLE_UPGRADE_CHECK"},
-		Hidden:  true,
-	}
-
 	concurrencyFlag = &cli.IntFlag{
 		Name:  "concurrency",
 		Usage: "Maximum number of hosts to configure in parallel, set to 0 for unlimited",
@@ -174,9 +159,6 @@ func initConfig(ctx *cli.Context) error {
 
 func displayCopyright(ctx *cli.Context) error {
 	fmt.Printf("k0sctl %s Copyright 2023, k0sctl authors.\n", k0sctl.Version)
-	if !ctx.Bool("disable-telemetry") {
-		fmt.Println("Anonymized telemetry of usage will be sent to the authors.")
-	}
 	fmt.Println("By continuing to use k0sctl you agree to these terms:")
 	fmt.Println("https://k0sproject.io/licenses/eula")
 	return nil
@@ -199,28 +181,6 @@ func warnOldCache(_ *cli.Context) error {
 	return nil
 }
 
-const segmentWriteKey string = "oU2iC4shRUBfEboaO0FDuDIUk49Ime92"
-
-func initAnalytics(ctx *cli.Context) error {
-	if ctx.Bool("disable-telemetry") {
-		log.Tracef("disabling telemetry")
-		return nil
-	}
-
-	client, err := segment.NewClient(segmentWriteKey)
-	if err != nil {
-		return err
-	}
-	analytics.Client = client
-
-	return nil
-}
-
-func closeAnalytics(_ *cli.Context) error {
-	analytics.Client.Close()
-	return nil
-}
-
 func initManager(ctx *cli.Context) error {
 	c, ok := ctx.Context.Value(ctxConfigKey{}).(*v1beta1.Cluster)
 	if c == nil || !ok {
