@@ -5,6 +5,7 @@ import (
 
 	"github.com/k0sproject/k0sctl/pkg/apis/k0sctl.k0sproject.io/v1beta1"
 	"github.com/k0sproject/k0sctl/pkg/apis/k0sctl.k0sproject.io/v1beta1/cluster"
+	"github.com/k0sproject/rig/exec"
 	"github.com/sirupsen/logrus"
 )
 
@@ -24,6 +25,10 @@ func (p *InstallBinaries) Prepare(config *v1beta1.Cluster) error {
 	p.Config = config
 	p.hosts = p.Config.Spec.Hosts.Filter(func(h *cluster.Host) bool {
 
+		if h.Reset && h.Metadata.K0sBinaryVersion != nil {
+			return false
+		}
+
 		// Upgrade is handled in UpgradeControllers/UpgradeWorkers phases
 		if h.Metadata.NeedsUpgrade {
 			return false
@@ -36,7 +41,23 @@ func (p *InstallBinaries) Prepare(config *v1beta1.Cluster) error {
 
 // ShouldRun is true when the phase should be run
 func (p *InstallBinaries) ShouldRun() bool {
-	return len(p.hosts) > 0
+	return len(p.hosts) > 0 || !p.IsWet()
+}
+
+// DryRun reports what would happen if Run is called.
+func (p *InstallBinaries) DryRun() error {
+	return p.parallelDo(
+		p.Config.Spec.Hosts.Filter(func(h *cluster.Host) bool { return h.Metadata.K0sBinaryTempFile != "" }),
+		func(h *cluster.Host) error {
+			p.DryMsgf(h, "install k0s %s binary from %s to %s", p.Config.Spec.K0s.Version, h.Metadata.K0sBinaryTempFile, h.Configurer.K0sBinaryPath())
+			if err := h.Execf(`chmod +x "%s"`, h.Metadata.K0sBinaryTempFile, exec.Sudo(h)); err != nil {
+				logrus.Warnf("%s: failed to chmod k0s temp binary for dry-run: %s", h, err.Error())
+			}
+			h.Configurer.SetPath("K0sBinaryPath", h.Metadata.K0sBinaryTempFile)
+			h.Metadata.K0sBinaryVersion = p.Config.Spec.K0s.Version
+			return nil
+		},
+	)
 }
 
 // Run the phase
