@@ -5,7 +5,6 @@ import (
 	"sync"
 
 	"github.com/k0sproject/k0sctl/pkg/apis/k0sctl.k0sproject.io/v1beta1"
-	"github.com/k0sproject/k0sctl/pkg/apis/k0sctl.k0sproject.io/v1beta1/cluster"
 	"github.com/logrusorgru/aurora"
 	log "github.com/sirupsen/logrus"
 )
@@ -92,10 +91,6 @@ type afterhook interface {
 	After(error) error
 }
 
-type propsetter interface {
-	SetProp(string, interface{})
-}
-
 type withcleanup interface {
 	CleanUp()
 }
@@ -235,15 +230,6 @@ func (m *Manager) Run() error {
 			}
 		}
 
-		if p, ok := p.(propsetter); ok {
-			if m.Config.Spec.K0s == nil {
-				m.Config.Spec.K0s = &cluster.K0s{Metadata: cluster.K0sMetadata{}}
-			}
-			if m.Config.Spec.K0s.Metadata.ClusterID != "" {
-				p.SetProp("clusterID", m.Config.Spec.K0s.Metadata.ClusterID)
-			}
-		}
-
 		text := Colorize.Green("==> Running phase: %s").String()
 		log.Infof(text, title)
 
